==> qtjambi-qt3drender-debuginfo-linux-x64-6.5.3.jar: sources/QtJambi3DRender/QAbstractTextureImage_shell.h <==
#ifndef QABSTRACTTEXTUREIMAGE_SHELL_H
#define QABSTRACTTEXTUREIMAGE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <Qt3DRender/qabstracttextureimage.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qnodeid.h>
#include <Qt3DRender/qabstracttexture.h>
#include <Qt3DRender/qtextureimagedatagenerator.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QAbstractTextureImage_shell : public Qt3DRender::QAbstractTextureImage, public QtJambiShellInterface
{
public:
    QAbstractTextureImage_shell(Qt3DCore::QNode* parent0 = nullptr);
    ~QAbstractTextureImage_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QSharedPointer<Qt3DRender::QTextureImageDataGenerator> dataGenerator() const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractTextureImage_access : public Qt3DRender::QAbstractTextureImage
{
    void __qt_notifyDataGeneratorChanged(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_dataGenerator(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QABSTRACTTEXTUREIMAGE_SHELL_H

==> qtjambi-qt3drender-debuginfo-linux-x64-6.5.5.jar: sources/QtJambi3DRender/QAbstractTextureImage_shell.h <==
#ifndef QABSTRACTTEXTUREIMAGE_SHELL_H
#define QABSTRACTTEXTUREIMAGE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <Qt3DRender/qabstracttextureimage.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DCore/qnode.h>
#include <Qt3DCore/qnodeid.h>
#include <Qt3DRender/qabstracttexture.h>
#include <Qt3DRender/qtextureimagedatagenerator.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QAbstractTextureImage_shell : public Qt3DRender::QAbstractTextureImage, public QtJambiShellInterface
{
public:
    QAbstractTextureImage_shell(Qt3DCore::QNode* parent0 = nullptr);
    ~QAbstractTextureImage_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QSharedPointer<Qt3DRender::QTextureImageDataGenerator> dataGenerator() const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractTextureImage_access : public Qt3DRender::QAbstractTextureImage
{
    void __qt_notifyDataGeneratorChanged(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_dataGenerator_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QABSTRACTTEXTUREIMAGE_SHELL_H
